#ifdef E_TYPEDEFS
#else
#ifndef E_INT_CONFIG_DISPLAY_H
#define E_INT_CONFIG_DISPLAY_H

E_Config_Dialog *e_int_config_display(E_Container *con, const char *params __UNUSED__);

#endif
#endif
